OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Begäran misslyckades, nätverksanslutning ej tillgänglig!",
    "Request unauthorized. Are you logged in?" : "Ogiltig begäran. Är du inloggad?",
    "Request forbidden. Are you an admin?" : "Begäran förbjuden. Är du administratör?",
    "Token expired or app not enabled! Reload the page!" : "Polletten föråldrad eller så är applikationen inte aktiverad! Uppdatera sidan.",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "Internt serverfel! Vänligen kontrollera din loggfil under data/nextcloud.log för mer information!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "Förfrågan misslyckades. Nextcloud är för närvarande i underhållsläge!",
    "Can not add feed: Exists already" : "Kan inte lägga till: flödet existerar redan",
    "Articles without feed" : "Artiklar utan flöde",
    "Can not add folder: Exists already" : "Kan inte lägga till: mappen existerar redan",
    "News" : "Nyheter",
    "An RSS/Atom feed reader" : "En RSS/Atom feed-läsare",
    "Use system cron for updates" : "Använda \"system cron\" för uppdateringar",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Inaktivera detta om du använder en anpassad uppdaterare så som Python-uppdateraren som ingår i appen",
    "Purge interval" : "Utrensningsintervall",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minimum antal sekunder efter det att borttagna flöden och mappar tas bort från databasen; värden under 60 sekunder ignoreras",
    "Maximum read count per feed" : "Maximalt läsantal per flöde",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off" : "Definiera maximalt antal artiklar som kan läsas per flöde som inte blir borttaget av uppstädningen; om gamla artiklar återuppstår när de lästs, öka detta värde; negativa värden som -1 stänger av funktionen",
    "Maximum redirects" : "Maximala omdirigeringar",
    "How many redirects the feed fetcher should follow" : "Hur många omdirigeringar flödet skall tillåtas följa",
    "Maximum feed page size" : "Maximum storlek på flödessidan",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximum storlek på flödet i bytes. Om RSS/Atom sidan är större än detta värde, kommer uppdateringen att avbrytas.",
    "Feed fetcher timeout" : "Timeout för flödes-hämtare",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximalt antal sekunder att vänta på att RSS/Atom flödet skall ladda. Om det tar längre tid avbryts uppdateringen.",
    "Explore Service URL" : "Utforska tjänst-URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Om angiven kommer denna tjänsts URL bli förfrågad om visning av flöden i flödet för utforskarsektionen. För att falla tillbaks på den inbyggda utforskar tjänsten, lämna detta inmatningsfält tomt",
    "For more information check the wiki" : "För mer information, se wiki.",
    "Saved" : "Sparad",
    "Download" : "Ladda ned",
    "Close" : "Stäng",
    "filter" : "filter",
    "Language" : "Språk",
    "Subscribe" : "Prenumerera",
    "Got more awesome feeds? Share them with us!" : "Har du fler häftiga flöden? Dela dem med oss!",
    "No articles available" : "Inga artiklar tillgängliga",
    "No unread articles available" : "Inga olästa artiklar tillgängliga",
    "Open website" : "Öppna webbplats",
    "Star article" : "Stjärnmärk artikel",
    "Unstar article" : "Ta bort stjärnmärke på artikel",
    "Keep article unread" : "Behåll artikel oläst",
    "Remove keep article unread" : "Ta bort behåll artikel oläst",
    "by" : "av",
    "from" : "från",
    "Play audio" : "Spela ljud",
    "Download video" : "Ladda ned video",
    "Download audio" : "Ladda ned ljud",
    "Keyboard shortcut" : "Tangentbordsgenvägar",
    "Description" : "Beskrivning",
    "right" : "Höger",
    "Jump to next article" : "Hoppa till nästkommande artikel",
    "left" : "vänster",
    "Jump to previous article" : "Hoppa till föregående artikel",
    "Toggle star article" : "Växla stjärnmärkning av artiklar",
    "Star article and jump to next one" : "Stärnmärk artikel och hoppa till nästa",
    "Toggle keep current article unread" : "Aktivera för att hålla aktuell artikel oläst",
    "Open article in new tab" : "Öppna artikeln i ny flik",
    "Toggle expand article in compact view" : "Aktivera för att expandera artikeln i kompakt vy",
    "Refresh" : "Uppdatera",
    "Load next feed" : "Ladda nästkommande flöde",
    "Load previous feed" : "Ladda föregående flöde",
    "Load next folder" : "Ladda nästkommande mapp",
    "Load previous folder" : "Ladda föregående mapp",
    "Scroll to active navigation entry" : "Skrolla till aktiv navigations-post",
    "Focus search field" : "Fokuserat sökfält",
    "Mark current article's feed/folder read" : "Markera nuvarande artikels flöde/mapp som läst",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax- eller webcron-läge upptäckt! Dina flöden kommer inte uppdateras!",
    "How to set up the operating system cron" : "Hur man ställer in cron från operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installera och konfigurera en snabbare parallell uppdaterare som använder programmet Nyheter uppdatering API",
    "Web address" : "Webbadress",
    "Feed exists already!" : "Flödet finns redan!",
    "Folder" : "Mapp",
    "No folder" : "Ingen mapp",
    "New folder" : "Ny mapp",
    "Folder name" : "Mappnamn",
    "Go back" : "Gå tillbaks",
    "Folder exists already!" : "Katalogen finns redan",
    "Credentials" : "Inloggningsuppgifter",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundläggande HTTP-autentiseringsuppgifter måste lagras okrypterade! Alla med tillgång till servern eller databasen kommer att kunna få tillgång till dem!",
    "Username" : "Användarnamn",
    "Password" : "Lösenord",
    "New Folder" : "Ny mapp",
    "Create" : "Skapa",
    "Explore" : "Utforska",
    "Update failed more than 50 times" : "Uppdatering misslyckades mer än 50 gånger",
    "Deleted feed" : "Raderade flöde",
    "Undo delete feed" : "Ångra radera flöde",
    "Rename" : "Byt namn",
    "Menu" : "Meny",
    "Mark read" : "Markera som läst",
    "Unpin from top" : "Ta bort från toppen",
    "Pin to top" : "Fäst i toppen",
    "Newest first" : "Nyaste först",
    "Oldest first" : "Äldst först",
    "Default order" : "Standardordning",
    "Enable full text" : "Aktivera fulltext",
    "Disable full text" : "Avaktivera fulltext",
    "Unread updated" : "Markera som oläst",
    "Ignore updated" : "Ignorera uppdaterad",
    "Open feed URL" : "Öppna flödes-URL",
    "Delete" : "Radera",
    "Dismiss" : "Avfärda",
    "Collapse" : "Dölj",
    "Deleted folder" : "Raderad mapp",
    "Undo delete folder" : "Ångra radera mapp",
    "Starred" : "Stjärnmärkt",
    "Unread articles" : "Olästa artiklar",
    "All articles" : "Alla artiklar",
    "Settings" : "Inställningar",
    "Disable mark read through scrolling" : "Stäng av markerad som läst vid skrollning",
    "Compact view" : "Kompakt vy",
    "Expand articles on key navigation" : "Expandera artiklar vid hantering",
    "Show all articles" : "Visa alla artiklar",
    "Reverse ordering (oldest on top)" : "Omvänd ordning (äldst överst)",
    "Subscriptions (OPML)" : "Prenumerationer (OPML)",
    "Import" : "Importera",
    "Export" : "Exportera",
    "Error when importing: File does not contain valid OPML" : "Fel vid importering: Fil innehåller inte giltig OPML",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Fel vid import: OPML innehåller varken flöden eller mappar",
    "Unread/Starred Articles" : "Olästa/Stjärnmärkta artiklar",
    "Error when importing: file does not contain valid JSON" : "Fel vid import: filen innehåller ej giltig JSON",
    "Help" : "Hjälp",
    "Keyboard shortcuts" : "Kortkommandon",
    "Documentation" : "Dokumentation",
    "Report a bug" : "Rapportera ett problem"
},
"nplurals=2; plural=(n != 1);");
